@@ -61,8 +61,8 @@ class MySQLModel(data_algebra.db_model.DBModel):
 
     def __init__(self):
         op_replacements = data_algebra.db_model.db_default_op_replacements.copy()
-        op_replacements['std'] = 'STDDEV_SAMP'
-        op_replacements['var'] = 'VAR_SAMP'
+        op_replacements["std"] = "STDDEV_SAMP"
+        op_replacements["var"] = "VAR_SAMP"
         data_algebra.db_model.DBModel.__init__(
             self,
             string_type="CHAR",
@@ -89,7 +89,9 @@ def example_handle():
     """
     # TODO: parameterize this
     assert have_sqlalchemy
-    db_engine = sqlalchemy.engine.create_engine("mysql+pymysql://jmount@localhost/jmount")
+    db_engine = sqlalchemy.engine.create_engine(
+        "mysql+pymysql://jmount@localhost/jmount"
+    )
     db_handle = MySQLModel().db_handle(conn=db_engine, db_engine=db_engine)
     db_handle.db_model.prepare_connection(db_handle.conn)
     return db_handle
