@@ -64,13 +64,13 @@ def table_is_keyed_by_columns(table, column_names: Iterable[str]) -> bool:
 
 
 # noinspection PyBroadException
-def _mk_type_conversion_table():
+def _mk_type_conversion_table() -> Dict[type, type]:
     """
     Build up conversion from type aliases we do not want into standard types. Eat any errors or warnings during table
     construction.
     """
 
-    type_conversions_table = dict()
+    type_conversions_table: Dict[type, type] = dict()
     # DeprecationWarning: `np.bool` is a deprecated alias for the builtin `bool`.
     # To silence this warning, use `bool` by itself. Doing this will not modify any behavior and is safe.
     # If you specifically wanted the numpy scalar type, use `np.bool_` here.
@@ -133,7 +133,6 @@ def map_type_to_canonical(v: type) -> type:
     :return: type
     """
     try:
-        # noinspection PyTypeChecker
         return type_conversions[v]
     except KeyError:
         pass
@@ -190,7 +189,9 @@ def guess_column_types(
     if (d.shape[0] <= 0) or (d.shape[1] <= 0):
         return dict()
     if columns is None:
-        columns = d.columns.copy()
+        columns = list(d.columns)
+    else:
+        columns = list(columns)
     assert len(set(columns) - set(d.columns)) == 0
     if len(columns) <= 0:
         return dict()
